@@ -213,6 +213,16 @@ impl Api{
             }
         }
     }
+    pub async fn open_str(url: &str) -> Result<Self, ()>{
+        let url: Url = match url.parse(){
+            Ok(url) => {
+                let url: Url = url;
+                url
+            }
+            Err(_) => { return Err(()) }
+        };
+        Self::open(url).await
+    }
     pub async fn close(&mut self) -> Result<(), ()>{
         match self.client.close().await{
             Ok(_) => { Ok(()) }
